package ru.mai.dep806.mvcapp.services;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;
import ru.mai.dep806.mvcapp.ApplicationException;
import ru.mai.dep806.mvcapp.DaoFactory;
import ru.mai.dep806.mvcapp.dao.UserDao;
import ru.mai.dep806.mvcapp.model.User;
import ru.mai.dep806.mvcapp.util.CryptoUtil;

/**
 * Created with IntelliJ IDEA.
 * User: Eugene
 * Date: 27.10.12
 * Time: 12:06
 * To change this template use File | Settings | File Templates.
 */
@Service
@Transactional
public class AdminService {

    @Autowired
    private UserDao userDao;
    private AuditService auditService;

    @Secured({"ROLE_MANAGER", "ROLE_CLIENT"})
    public void registerUser(User user, String plainPassword) {
        if (!StringUtils.hasText(plainPassword) || plainPassword.trim().length() < 5) {
            throw new ApplicationException("Password length should not less then 5 symbols");
        }

        user.setPasswordHash(CryptoUtil.digestPassword(plainPassword));

        // auditService.logRegisterUser(user);

        userDao.insertUser(user);
    }

    public void setUserDao(UserDao userDao) {
        this.userDao = userDao;
    }
}
