package ru.mai.dep806.mvcapp.controllers;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.Errors;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import ru.mai.dep806.mvcapp.model.User;
import ru.mai.dep806.mvcapp.model.UserForm;
import ru.mai.dep806.mvcapp.services.AdminService;

import javax.servlet.http.HttpSession;
import javax.validation.Valid;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * Controller for index page.
 */
@Controller
public class WelcomeController {

    private AtomicInteger visitorCount = new AtomicInteger();

    @Autowired
    private AdminService adminService;

    @RequestMapping("/index.html")
    public String index(Model model) {
        model.addAttribute("visitorCount", visitorCount.incrementAndGet());
        return "/WEB-INF/jsp/index.jsp";
    }

    @RequestMapping(value = "/register.html", method = RequestMethod.GET)
    public String registerView(@ModelAttribute UserForm userForm, Errors errors) {
        return "/WEB-INF/jsp/register.jsp";
    }

    @RequestMapping(value = "/register.html", method = RequestMethod.POST)
    public String registerSubmit(@Valid UserForm userForm, Errors errors, HttpSession session) {

        if (!userForm.getPlainPassword().equals(userForm.getRepeatPassword())) {
            errors.rejectValue("repeatPassword", "error.wrongRepeatPassword", "Неправильно введено подтверждение пароля");
        }

        if (errors.hasErrors()) {
            return "/WEB-INF/jsp/register.jsp";
        }

        session.setAttribute("currentUser", userForm);

        adminService.registerUser(convert(userForm), userForm.getPlainPassword());

        return "/WEB-INF/jsp/register.jsp";
    }

    private User convert(UserForm userForm) {
        User user = new User();
        user.setLogin(userForm.getLogin());
        user.setName(userForm.getName());

        return user;
    }

}
